Examples
========

Laser target
------------

A Gaussian laser pulse interacting with a target.

Automatically plot the simulation data with a callback `plot_results`.

Copy/download: :download:`laser-target.py <../../example/laser-target.py>`.

.. literalinclude:: ../../example/laser-target.py
    :language: python

Laser wakefield
---------------

For demostration of moving window.

Copy/download: :download:`lwfa.py <../../example/lwfa.py>`.

.. literalinclude:: ../../example/lwfa.py
    :language: python

QED photons
-----------

For demostration of QED photons and callback turning on/off QED.

The example has a :code:`enable_radiation` switch that enables radiation at desired time.

Copy/download: :download:`photons.py <../../example/photons.py>`.

.. literalinclude:: ../../example/photons.py
    :language: python